Input

Struct Input 

pub struct Input<'h> { /* private fields */ }
Unfortunately, Japanese is highly contextual, surrounding charcaters are needed for accurate romanization. This struct can keep surrounding charcaters by storing the entire haystack and the start offset.

Implementations

Source

impl<'h> Input<'h>

pub fn new<H: ?Sized + AsRef<str>>(haystack: &'h H, start: usize) -> Self

pub fn haystack(&self) -> &'h str

pub fn start(&self) -> usize

pub fn is_empty(&self) -> bool