pub struct Input<'h> { /* private fields */ }Expand description
Unfortunately, Japanese is highly contextual, surrounding charcaters are needed for accurate romanization. This struct can keep surrounding charcaters by storing the entire haystack and the start offset.
Implementations